# Detect the distribution in use
%global __despace head -n 1 | tr -d '[:space:]' | sed -e 's/[(].*[)]//g'
%global __lower4 cut -c 1-4 | tr '[:upper:]' '[:lower:]'
%global __distfile %([ -f /etc/SuSE-release ] && echo /etc/SuSE-release || echo /etc/redhat-release)
%global __distinit %(sed -e 's/ release .*//' -e 's/\\([A-Za-z]\\)[^ ]*/\\1/g' %{__distfile} | %{__despace} | %{__lower4})
%global __distvers %(sed -e 's/.* release \\([^. ]*\\).*/\\1/' %{__distfile} | %{__despace})
# Identify Alma, CentOS, CentOS Stream and Rocky Linux as rhel
%if "%{__distinit}" == "a" || "%{__distinit}" == "c" || "%{__distinit}" == "cl" || "%{__distinit}" == "cs" || "%{__distinit}" == "rl"
%global __distinit rhel
%endif
# Dist tag for Fedora is still "fc"
%if "%{__distinit}" == "f"
%global __distinit fc
%endif

%global rpm_version 2.2.4
%global cpan_version %(echo %{rpm_version} | awk -F. '{ if ($3 == 0) { printf "%d.%03d", $1, $2 } else { printf "%d.%03d%03d", $1, $2, $3 } }')

# Use weak dependencies where available
%global have_weak_deps 0%{?fedora} > 20 || 0%{?rhel} > 7

Name:		perl-Function-Parameters
Version:	%{rpm_version}
Release:	1.%{__distinit}%{__distvers}
Summary:	Subroutine definitions with parameter lists
License:	GPL-1.0-or-later OR Artistic-1.0-Perl
URL:		https://metacpan.org/release/Function-Parameters
Source0:	https://cpan.metacpan.org/authors/id/M/MA/MAUKE/Function-Parameters-%{cpan_version}.tar.gz
# Module Build
BuildRequires:	coreutils
BuildRequires:	findutils
BuildRequires:	gawk
BuildRequires:	gcc
BuildRequires:	make
BuildRequires:	perl-devel >= 4:5.14.0
BuildRequires:	perl-generators
BuildRequires:	perl-interpreter
BuildRequires:	perl(ExtUtils::MakeMaker)
BuildRequires:	perl(File::Find)
BuildRequires:	perl(File::Spec)
# Module Runtime
BuildRequires:	perl(Carp)
BuildRequires:	perl(overload)
BuildRequires:	perl(Scalar::Util)
BuildRequires:	perl(strict)
BuildRequires:	perl(warnings)
BuildRequires:	perl(warnings::register)
BuildRequires:	perl(XSLoader)
# Optional Functionality
BuildRequires:	perl(Moose::Util::TypeConstraints)
# Test Suite
BuildRequires:	perl(constant)
BuildRequires:	perl(FindBin)
BuildRequires:	perl(Hash::Util) >= 0.07
BuildRequires:	perl(integer)
BuildRequires:	perl(Test::Fatal)
BuildRequires:	perl(Test::More)
BuildRequires:	perl(utf8)
# Optional Tests
BuildRequires:	perl(Moose)
BuildRequires:	perl(Moose::Util)
BuildRequires:	perl(MooseX::Types)
BuildRequires:	perl(MooseX::Types::Moose)
BuildRequires:	perl(threads)
BuildRequires:	perl(threads::shared)
# Dependencies
%if 0%{?fedora} < 38 && 0%{?rhel} < 10
Requires:	perl(:MODULE_COMPAT_%(eval "`perl -V:version`"; echo $version))
%endif
%if %{have_weak_deps}
Recommends:	perl(Moose::Util::TypeConstraints)
%else
Requires:	perl(Moose::Util::TypeConstraints)
%endif

# Avoid private shared object provides
%{?perl_default_filter}

%description
This module extends Perl with keywords that let you define functions with
parameter lists. It uses Perl's keyword plugin API, so it works reliably
and doesn't require a source filter.

%prep
%setup -q -n Function-Parameters-%{cpan_version}

%build
perl Makefile.PL INSTALLDIRS=vendor OPTIMIZE="%{optflags}"
make %{?_smp_mflags}

%install
make pure_install DESTDIR=%{buildroot}
find %{buildroot} -type f -name .packlist -delete
find %{buildroot} -type f -name '*.bs' -empty -delete
%{_fixperms} -c %{buildroot}

%check
make test

%files
%doc Changes README
%{perl_vendorarch}/auto/Function/
%{perl_vendorarch}/Function/
%{_mandir}/man3/Function::Parameters.3*
%{_mandir}/man3/Function::Parameters::Info.3*

%changelog
* Sun Jul 16 2023 Paul Howarth <paul@city-fan.org> - 2.2.4-1
- Update to 2.002004 (rhbz#2223063)
  - Remove 'perl -T' from t/info.t, so we can run on perls compiled without
    support for taint mode; the test didn't actually care about taint anyway

* Sat Jul 15 2023 Paul Howarth <paul@city-fan.org> - 2.2.3-2
- Perl 5.38 rebuild

* Wed Apr 19 2023 Paul Howarth <paul@city-fan.org> - 2.2.3-1
- Update to 2.002003 (rhbz#2188007)
  - Fix line numbers after inlined type checks (GH#42)
    Previously, the code for type checks was inlined literally, so if a
    particular check took 5 lines of code, all the following line numbers in
    the source file would be off by 5 (they would be "pushed down" by the
    interpolated code); these bad line numbers would show up in error messages
    from Perl (including warn and die) as well as __LINE__ and caller (and
    thus stack traces)
- Weaken dependency on perl(Moose::Util::TypeConstraints)

* Sun Apr  2 2023 Paul Howarth <paul@city-fan.org> - 2.2.2-1
- Update to 2.002002 (rhbz#2183727)
  - Fix (hopefully) Windows builds using nmake.exe
  - Work around old versions of ExtUtils::MakeMaker not providing
    is_make_type(), whose version dependency is undocumented (sigh)
  - Restrict GNU syntax for exporting variables to type 'gmake'; should fix
    building on BSD, Solaris, etc.
  - Declare dependency on ExtUtils::MakeMaker 7+ and remove compatibility code
    for older versions

* Sat Apr  1 2023 Paul Howarth <paul@city-fan.org> - 2.2.0-1
- Update to 2.002
  - Provide //= for default arguments, which are also used when the caller
    passes in undef
  - Provide more type combinators in parameter declarations: In addition to |
    (union types), now ~ & / are also supported (for
    complement types, intersection types, and alternative types, respectively)
  - Enable type coercions: if a parameter has a declared type and that type
    supports coercions ($type->has_coercion returns true), call its
    ->coerce($value) method to transform arguments before type checking
  - Enable inline type checks: if a parameter has a declared type and that
    type supports inlining ($type->can_be_inlined returns true), its inline
    code (as provided by ->inline_check('$value')) is baked into the function
    definition instead of a call to ->check($value), which may speed up type
    checks
  - Move a big chunk of tests to xt/ (author testing only)
  - Remove xt/ from the distribution
  - Enable parallel testing by default (with -j4)

* Mon Mar 27 2023 Paul Howarth <paul@city-fan.org> - 2.1.6-1
- Update to 2.001006 (rhbz#2182064)
  - Work around perl core issue GH#20950 (use re "eval" doesn't capture lexical
    %%^H environment like eval() does and stringifies it instead), by
    downgrading the previous hard error to a warning (in the new category
    'Function::Parameters') and switching Function::Parameters off in the
    affected scope

* Fri Jan 27 2023 Paul Howarth <paul@city-fan.org> - 2.1.5-1
- Update to 2.001005 (rhbz#2164971)
  - Fix failures with perl 5.37.5..5.37.6 caused by new internal opcode
    structure for anonymous subs

* Fri Jan 20 2023 Paul Howarth <paul@city-fan.org> - 2.1.4-1
- Update to 2.001004 (rhbz#2162566)
  - Drop Dir::Self test dependency (use FindBin instead)
- Use SPDX-format license tag

* Fri Jun  3 2022 Paul Howarth <paul@city-fan.org> - 2.1.3-15
- Perl 5.36 rebuild

* Mon May 24 2021 Paul Howarth <paul@city-fan.org> - 2.1.3-12
- Perl 5.34 rebuild

* Mon Jun 29 2020 Paul Howarth <paul@city-fan.org> - 2.1.3-9
- Perl 5.32 rebuild

* Mon Jun 10 2019 Paul Howarth <paul@city-fan.org> - 2.1.3-7
- Perl 5.30 rebuild

* Tue Mar 12 2019 Paul Howarth <paul@city-fan.org> - 2.1.3-6
- Import from Fedora

* Fri Feb 01 2019 Fedora Release Engineering <releng@fedoraproject.org> - 2.1.3-5
- Rebuilt for https://fedoraproject.org/wiki/Fedora_30_Mass_Rebuild

* Fri Jul 13 2018 Fedora Release Engineering <releng@fedoraproject.org> - 2.1.3-4
- Rebuilt for https://fedoraproject.org/wiki/Fedora_29_Mass_Rebuild

* Fri Jun 29 2018 Jitka Plesnikova <jplesnik@redhat.com> - 2.1.3-3
- Perl 5.28 rebuild

* Thu Feb 08 2018 Fedora Release Engineering <releng@fedoraproject.org> - 2.1.3-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_28_Mass_Rebuild

* Mon Nov 13 2017 Petr Pisar <ppisar@redhat.com> - 2.1.3-1
- 2.001003 bump

* Thu Nov 09 2017 Petr Pisar <ppisar@redhat.com> - 2.1.2-1
- 2.001002 bump

* Thu Aug 03 2017 Fedora Release Engineering <releng@fedoraproject.org> - 2.1.1-3
- Rebuilt for https://fedoraproject.org/wiki/Fedora_27_Binutils_Mass_Rebuild

* Thu Jul 27 2017 Fedora Release Engineering <releng@fedoraproject.org> - 2.1.1-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_27_Mass_Rebuild

* Mon Jul 03 2017 Petr Pisar <ppisar@redhat.com> - 2.1.1-1
- 2.001001 bump

* Tue Jun 06 2017 Jitka Plesnikova <jplesnik@redhat.com> - 2.0.7-2
- Perl 5.26 rebuild

* Tue May 16 2017 Petr Pisar <ppisar@redhat.com> - 2.0.7-1
- 2.000007 bump

* Tue Apr 18 2017 Petr Pisar <ppisar@redhat.com> - 2.0.6-2
- 2.000006 bump

* Mon Apr 03 2017 Petr Pisar <ppisar@redhat.com> - 2.0.3-1
- 2.000003 bump

* Tue Mar 28 2017 Petr Pisar <ppisar@redhat.com> - 2.0.2-1
- 2.000002 bump

* Fri Mar 17 2017 Petr Pisar <ppisar@redhat.com> - 1.0706-1
- 1.0706 bump

* Sat Feb 11 2017 Fedora Release Engineering <releng@fedoraproject.org> - 1.0705-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_26_Mass_Rebuild

* Wed Jun 15 2016 Petr Pisar <ppisar@redhat.com> - 1.0705-1
- 1.0705 bump

* Mon May 16 2016 Jitka Plesnikova <jplesnik@redhat.com> - 1.0704-2
- Perl 5.24 rebuild

* Mon Feb 15 2016 Petr Pisar <ppisar@redhat.com> - 1.0704-1
- 1.0704 bump

* Thu Feb 04 2016 Petr Pisar <ppisar@redhat.com> 1.0703-1
- Specfile autogenerated by cpanspec 1.78.
- Address mistakes found by review
